==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/preferencesdialog.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef PREFERENCESDIALOG_H
#define PREFERENCESDIALOG_H

#include "ui_preferencesdialog.h"
#include <QDialog>

class Config;
class MPD;
class ServerModel;
class QButtonGroup;
class QItemSelectionModel;

class PreferencesDialog : public QDialog, private Ui::PreferencesDialog {
	Q_OBJECT

private:
	Config *config;
	MPD *mpd;
	ServerModel *serverModel;
	QItemSelectionModel *serverSel;
	QButtonGroup *positionGroup;
	QString origPattern;

public:
	PreferencesDialog(QWidget *parent);

private:
	void setFontString(QFont);
	void addViewPage(QTreeWidgetItem *);

private slots:
	void on_addButton_clicked();
	void on_cancelButton_clicked();
	void on_categoryList_currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *);
	void on_deleteButton_clicked();
	void on_downButton_clicked();
	void on_fontButton_clicked();
	void on_okButton_clicked();
	void on_patternLine_textChanged(const QString &);
	void on_testLine_textChanged(const QString &);
	void on_upButton_clicked();
	void serverSelectionChanged();
};
#endif

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/preferencesdialog.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef PREFERENCESDIALOG_H
#define PREFERENCESDIALOG_H

#include "ui_preferencesdialog.h"
#include <QDialog>

class PreferencesDialog : public QDialog, private Ui::PreferencesDialog {
	Q_OBJECT

private:
	class Config *m_config;
	class MPD *m_mpd;
	class ServerModel *m_serverModel;
	class QItemSelectionModel *m_serverSel;
	class QButtonGroup *m_positionGroup;
	QString m_origPattern;
	QMap<QTreeWidgetItem*, int> m_relation;
	void alternatingChanged();

public:
	PreferencesDialog(QWidget *parent);

private:
	void setFontString(const QFont &);

private slots:
	void on_addButton_clicked();
	void on_applyButton_clicked();
	void on_cancelButton_clicked();
	void on_categoryList_currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *);
	void on_deleteButton_clicked();
	void on_downButton_clicked();
	void on_fontButton_clicked();
	void on_okButton_clicked();
	void on_patternLine_textChanged(const QString &);
	void on_testLine_textChanged(const QString &);
	void on_upButton_clicked();
	void serverSelectionChanged();
};
#endif
